@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2014-2020 Greenbone Networks GmbH
+# Copyright (C) 2014-2021 Greenbone Networks GmbH
 #
 # SPDX-License-Identifier: AGPL-3.0-or-later
 #
@@ -22,24 +22,20 @@
 import logging
 
 from typing import List, Dict, Optional, Iterator, Tuple
+from pathlib import Path
+from time import time
 
-from packaging.specifiers import SpecifierSet
-from packaging.version import parse as parse_version
-
-from ospd_openvas.db import NVT_META_FIELDS, OpenvasDB, MainDB, BaseDB, RedisCtx
+from ospd.errors import RequiredArgument
 from ospd_openvas.errors import OspdOpenvasError
-from ospd_openvas.openvas import Openvas
+from ospd_openvas.db import NVT_META_FIELDS, OpenvasDB, MainDB, BaseDB, RedisCtx
 
+NVTI_CACHE_NAME = "nvticache"
 
 logger = logging.getLogger(__name__)
 
 LIST_FIRST_POS = 0
 LIST_LAST_POS = -1
 
-# actually the nvti cache with gvm-libs 10 should fit too but openvas was only
-# introduced with GVM 11 and gvm-libs 11
-SUPPORTED_NVTICACHE_VERSIONS_SPECIFIER = SpecifierSet('>=11.0')
-
 
 class NVTICache(BaseDB):
 
@@ -66,58 +62,17 @@ class NVTICache(BaseDB):
         self._ctx = None
         self.index = None
         self._main_db = main_db
-        self._nvti_cache_name = None
-
-    def _get_nvti_cache_name(self) -> str:
-        if not self._nvti_cache_name:
-            self._set_nvti_cache_name()
-
-        return self._nvti_cache_name
-
-    def _is_compatible_version(self, version: str) -> bool:
-        installed_version = parse_version(version)
-        return installed_version in SUPPORTED_NVTICACHE_VERSIONS_SPECIFIER
-
-    def _set_nvti_cache_name(self):
-        """Set nvticache name"""
-        version_string = Openvas.get_gvm_libs_version()
-        if not version_string:
-            raise OspdOpenvasError(
-                "Not possible to get the installed gvm-libs version. "
-                "Outdated openvas version. openvas version needs to be at "
-                "least 7.0.1."
-            )
-        # Remove pre-release sufix and git revision if exists
-        # as the gvm-libs version has the  format
-        # e.g "20.8+beta1-git-a41b140d-zero-padding"
-        version_string = version_string.split("+")[0]
-
-        if self._is_compatible_version(version_string):
-            self._nvti_cache_name = "nvticache{}".format(version_string)
-        else:
-            raise OspdOpenvasError(
-                "Error setting nvticache. Incompatible nvticache "
-                "version {}. Supported versions are {}.".format(
-                    version_string,
-                    ", ".join(
-                        [
-                            str(spec)
-                            for spec in SUPPORTED_NVTICACHE_VERSIONS_SPECIFIER
-                        ]
-                    ),
-                )
-            )
 
     @property
     def ctx(self) -> Optional[RedisCtx]:
         if self._ctx is None:
             self._ctx, self.index = OpenvasDB.find_database_by_pattern(
-                self._get_nvti_cache_name(), self._main_db.max_database_index
+                NVTI_CACHE_NAME, self._main_db.max_database_index
             )
         return self._ctx
 
     def get_feed_version(self) -> Optional[str]:
-        """ Get feed version of the nvti cache db.
+        """Get feed version of the nvti cache db.
 
         Returns the feed version or None if the nvt feed isn't available.
         """
@@ -125,10 +80,10 @@ class NVTICache(BaseDB):
             # no nvti cache db available yet
             return None
 
-        return OpenvasDB.get_single_item(self.ctx, self._get_nvti_cache_name())
+        return OpenvasDB.get_single_item(self.ctx, NVTI_CACHE_NAME)
 
     def get_oids(self) -> Iterator[Tuple[str, str]]:
-        """ Get the list of NVT file names and OIDs.
+        """Get the list of NVT file names and OIDs.
 
         Returns:
             A i. Each single list contains the filename
@@ -137,7 +92,7 @@ class NVTICache(BaseDB):
         return OpenvasDB.get_filenames_and_oids(self.ctx)
 
     def get_nvt_params(self, oid: str) -> Optional[Dict[str, str]]:
-        """ Get NVT's preferences.
+        """Get NVT's preferences.
 
         Arguments:
             oid: OID of VT from which to get the parameters.
@@ -173,7 +128,7 @@ class NVTICache(BaseDB):
 
     @staticmethod
     def _parse_metadata_tags(tags_str: str, oid: str) -> Dict[str, str]:
-        """ Parse a string with multiple tags.
+        """Parse a string with multiple tags.
 
         Arguments:
             tags_str: String with tags separated by `|`.
@@ -195,7 +150,7 @@ class NVTICache(BaseDB):
         return tags_dict
 
     def get_nvt_metadata(self, oid: str) -> Optional[Dict[str, str]]:
-        """ Get a full NVT. Returns an XML tree with the NVT metadata.
+        """Get a full NVT. Returns an XML tree with the NVT metadata.
 
         Arguments:
             oid: OID of VT from which to get the metadata.
@@ -205,7 +160,7 @@ class NVTICache(BaseDB):
         """
         resp = OpenvasDB.get_list_item(
             self.ctx,
-            "nvt:%s" % oid,
+            f"nvt:{oid}",
             start=NVT_META_FIELDS.index("NVT_FILENAME_POS"),
             end=NVT_META_FIELDS.index("NVT_NAME_POS"),
         )
@@ -259,7 +214,7 @@ class NVTICache(BaseDB):
         return custom
 
     def get_nvt_refs(self, oid: str) -> Optional[Dict[str, str]]:
-        """ Get a full NVT.
+        """Get a full NVT.
 
         Arguments:
             oid: OID of VT from which to get the VT references.
@@ -269,7 +224,7 @@ class NVTICache(BaseDB):
         """
         resp = OpenvasDB.get_list_item(
             self.ctx,
-            "nvt:%s" % oid,
+            f"nvt:{oid}",
             start=NVT_META_FIELDS.index("NVT_CVES_POS"),
             end=NVT_META_FIELDS.index("NVT_XREFS_POS"),
         )
@@ -286,7 +241,7 @@ class NVTICache(BaseDB):
         return refs
 
     def get_nvt_family(self, oid: str) -> str:
-        """ Get NVT family
+        """Get NVT family
         Arguments:
             oid: OID of VT from which to get the VT family.
 
@@ -295,12 +250,12 @@ class NVTICache(BaseDB):
         """
         return OpenvasDB.get_single_item(
             self.ctx,
-            'nvt:%s' % oid,
+            f"nvt:{oid}",
             index=NVT_META_FIELDS.index("NVT_FAMILY_POS"),
         )
 
     def get_nvt_prefs(self, oid: str) -> Optional[List[str]]:
-        """ Get NVT preferences.
+        """Get NVT preferences.
 
         Arguments:
             ctx: Redis context to be used.
@@ -309,11 +264,11 @@ class NVTICache(BaseDB):
         Returns:
             A list with the VT preferences.
         """
-        key = 'oid:%s:prefs' % oid
+        key = f'oid:{oid}:prefs'
         return OpenvasDB.get_list_item(self.ctx, key)
 
     def get_nvt_timeout(self, oid: str) -> Optional[str]:
-        """ Get NVT timeout
+        """Get NVT timeout
 
         Arguments:
             ctx: Redis context to be used.
@@ -324,12 +279,12 @@ class NVTICache(BaseDB):
         """
         return OpenvasDB.get_single_item(
             self.ctx,
-            'nvt:%s' % oid,
+            f"nvt:{oid}",
             index=NVT_META_FIELDS.index("NVT_TIMEOUT_POS"),
         )
 
     def get_nvt_tags(self, oid: str) -> Optional[Dict[str, str]]:
-        """ Get Tags of the given OID.
+        """Get Tags of the given OID.
 
         Arguments:
             ctx: Redis context to be used.
@@ -340,7 +295,7 @@ class NVTICache(BaseDB):
         """
         tag = OpenvasDB.get_single_item(
             self.ctx,
-            'nvt:%s' % oid,
+            f"nvt:{oid}",
             index=NVT_META_FIELDS.index('NVT_TAGS_POS'),
         )
         tags = tag.split('|')
@@ -355,3 +310,40 @@ class NVTICache(BaseDB):
 
     def force_reload(self):
         self._main_db.release_database(self)
+
+    def add_vt_to_cache(self, vt_id: str, vt: List[str]):
+        if not vt_id:
+            raise RequiredArgument('add_vt_to_cache', 'vt_id')
+        if not vt:
+            raise RequiredArgument('add_vt_to_cache', 'vt')
+        if not isinstance(vt, list) or len(vt) != 15:
+            raise OspdOpenvasError(f'Error trying to load the VT {vt} in cache')
+
+        OpenvasDB.add_single_list(self.ctx, vt_id, vt)
+
+        OpenvasDB.add_single_item(self.ctx, f'filename:{vt[0]}', [int(time())])
+
+    def get_file_checksum(self, file_abs_path: Path) -> str:
+        """Get file sha256 checksum or md5 checksum
+
+        Arguments:
+            file_abs_path: File to get the checksum
+
+        Returns:
+            The checksum
+        """
+        # Try to get first sha256 checksum
+        sha256sum = OpenvasDB.get_single_item(
+            self.ctx,
+            f'sha256sums:{file_abs_path}',
+        )
+        if sha256sum:
+            return sha256sum
+
+        # Search for md5 checksum
+        md5sum = OpenvasDB.get_single_item(
+            self.ctx,
+            f'md5sums:{file_abs_path}',
+        )
+        if md5sum:
+            return md5sum
