@@ -90,7 +90,7 @@ class TestOspdOpenvas(TestCase):
         dummy = DummyDaemon()
         logging.Logger.warning = Mock()
 
-        custom = {'a': u"\u0006"}
+        custom = {'a': "\u0006"}
         dummy.get_custom_vt_as_xml_str(
             '1.3.6.1.4.1.25623.1.0.100061', custom=custom
         )
@@ -121,7 +121,7 @@ class TestOspdOpenvas(TestCase):
         dummy = DummyDaemon()
         logging.Logger.warning = Mock()
 
-        sever = {'severity_base_vector': u"\u0006"}
+        sever = {'severity_base_vector': "\u0006"}
         dummy.get_severities_vt_as_xml_str(
             '1.3.6.1.4.1.25623.1.0.100061', severities=sever
         )
@@ -159,7 +159,7 @@ class TestOspdOpenvas(TestCase):
             '1': {
                 'id': '1',
                 'type': 'entry',
-                'default': u'\u0006',
+                'default': '\u0006',
                 'name': 'dns-fuzz.timelimit',
                 'description': 'Description',
             }
@@ -213,7 +213,7 @@ class TestOspdOpenvas(TestCase):
         dummy = DummyDaemon()
         logging.Logger.error = Mock()
 
-        dep = [u"\u0006"]
+        dep = ["\u0006"]
         dummy.get_dependencies_vt_as_xml_str(
             '1.3.6.1.4.1.25623.1.0.100061', vt_dependencies=dep
         )
@@ -236,7 +236,7 @@ class TestOspdOpenvas(TestCase):
         dummy = DummyDaemon()
         logging.Logger.warning = Mock()
 
-        ctime = u'\u0006'
+        ctime = '\u0006'
         dummy.get_creation_time_vt_as_xml_str(
             '1.3.6.1.4.1.25623.1.0.100061', vt_creation_time=ctime
         )
@@ -259,7 +259,7 @@ class TestOspdOpenvas(TestCase):
         dummy = DummyDaemon()
         logging.Logger.warning = Mock()
 
-        mtime = u'\u0006'
+        mtime = '\u0006'
         dummy.get_modification_time_vt_as_xml_str(
             '1.3.6.1.4.1.25623.1.0.100061', mtime
         )
@@ -281,7 +281,7 @@ class TestOspdOpenvas(TestCase):
     def test_get_summary_xml_failed(self):
         dummy = DummyDaemon()
 
-        summary = u'\u0006'
+        summary = '\u0006'
         logging.Logger.warning = Mock()
         dummy.get_summary_vt_as_xml_str('1.3.6.1.4.1.25623.1.0.100061', summary)
 
@@ -303,7 +303,7 @@ class TestOspdOpenvas(TestCase):
         dummy = DummyDaemon()
         logging.Logger.warning = Mock()
 
-        impact = u'\u0006'
+        impact = '\u0006'
         dummy.get_impact_vt_as_xml_str('1.3.6.1.4.1.25623.1.0.100061', impact)
 
         assert_called_once(logging.Logger.warning)
@@ -324,7 +324,7 @@ class TestOspdOpenvas(TestCase):
         dummy = DummyDaemon()
         logging.Logger.warning = Mock()
 
-        insight = u'\u0006'
+        insight = '\u0006'
         dummy.get_insight_vt_as_xml_str('1.3.6.1.4.1.25623.1.0.100061', insight)
 
         assert_called_once(logging.Logger.warning)
@@ -355,7 +355,7 @@ class TestOspdOpenvas(TestCase):
         dummy = DummyDaemon()
         logging.Logger.warning = Mock()
 
-        solution = u'\u0006'
+        solution = '\u0006'
         dummy.get_solution_vt_as_xml_str(
             '1.3.6.1.4.1.25623.1.0.100061', solution
         )
@@ -379,7 +379,7 @@ class TestOspdOpenvas(TestCase):
         dummy = DummyDaemon()
         logging.Logger.warning = Mock()
 
-        detection = u'\u0006'
+        detection = '\u0006'
         dummy.get_detection_vt_as_xml_str(
             '1.3.6.1.4.1.25623.1.0.100061', detection
         )
@@ -402,7 +402,7 @@ class TestOspdOpenvas(TestCase):
         dummy = DummyDaemon()
         logging.Logger.warning = Mock()
 
-        affected = u"\u0006" + "affected"
+        affected = "\u0006" + "affected"
         dummy.get_affected_vt_as_xml_str(
             '1.3.6.1.4.1.25623.1.0.100061', affected=affected
         )
